=====================================
 Using Stevedore in Your Application
=====================================

This tutorial is a step-by-step walk-through demonstrating how to
define plugins and then use stevedore to load and use them in your
application.

.. toctree::
   :maxdepth: 2

   naming
   creating_plugins
   loading
   testing

.. seealso::

   * :doc:`../essays/pycon2013`
   * `Using setuptools entry points`_
   * `Package Discovery and Resource Access using pkg_resources`_
   * `Using Entry Points to Write Plugins | Pylons`_
   * `importlib.metadata`_

.. _Using setuptools entry points: http://reinout.vanrees.org/weblog/2010/01/06/zest-releaser-entry-points.html
.. _Package Discovery and Resource Access using pkg_resources: http://pythonhosted.org/distribute/pkg_resources.html
.. _Using Entry Points to Write Plugins | Pylons: http://docs.pylonsproject.org/projects/pylons-webframework/en/latest/advanced_pylons/entry_points_and_plugins.html
.. _importlib.metadata: https://docs.python.org/3/library/importlib.metadata.html#entry-points
